datfilprefix='CO_HIPPO'
species='CO_ppbv'

case 1 of
  datfilprefix eq 'O3_HIPPO' and species eq 'O3_ppbv': begin
    ac_suff='_RA.ict'
    ps_label='ozone_spackman'
    pi_title='Spackman'
    lev=[5.*findgen(21),125.,150.,200.,300.,500.,1000.,2000.,3000.,5000.,10000.]
;    lev=0.+5.*findgen(31)
    model_species='O3'
    scale=1.e9 & unit='(ppbv)'
ylog=1
  end
  datfilprefix eq 'CO_HIPPO' and species eq 'CO_ppbv': begin
    ac_suff='_RA.ict'
    ps_label='co_wofsy'
    pi_title='Wofsy'
    lev=4.*findgen(31)
    lev=5.*findgen(31)
    lev=250.*findgen(31)/30.
    model_species='CO'
    scale=1.e9 & unit='(ppbv)'
  end
  datfilprefix eq 'CH4_HIPPO' and species eq 'CH4_ppbv': begin
    ac_suff='_RA.ict'
    ps_label='ch4_wofsy'
    pi_title='Wofsy'
    lev=4.*findgen(31)
    lev=5.*findgen(31)
    lev=1700.+1300.*findgen(31)/30.
    model_species='CH4'
    scale=1.e9 & unit='(ppbv)'
  end
  datfilprefix eq 'N2O_HIPPO' and species eq 'N2O_ppbv': begin
    ac_suff='_RA.ict'
    ps_label='n2o_wofsy'
    pi_title='Wofsy'
    lev=4.*findgen(31)
    lev=5.*findgen(31)
    lev=300+30.*findgen(31)/30.
    model_species='N2O'
    scale=1.e9 & unit='(ppbv)'
  end
  else: stop,'insitu data not defined, '+datfilprefix+', '+species
endcase

dates=[$
'20100324',$
'20100326',$
'20100329',$
'20100331',$
'20100402',$
'20100405',$
'20100408',$
'20100410',$
'20100413',$
'20100415',$
'20100416'$
]

nfiles=n_elements(dates)

; READ MODEL FLIGHT-TRACK FILE

dat_dir='./Flight_data/'
acdir='RAQMS/'

for nf=0,nfiles-1 do begin
openr,20,dat_dir+acdir+'hippo_'+dates(nf)+'_ra_track_mission.dat',/f77
  nummod=0L
  ntime=0L
  dum=''
  readu,20,nummod,ntime
  readu,20,dum
  temp=fltarr(nummod)
  datamod=fltarr(nummod,ntime)
  for i=0L,ntime-1L do begin
    readu,20,temp
    datamod(*,i)=temp
  endfor
  close,20
; HIPPO
;  datamod(0,*)=xjday
;  datamod(1,*)=utcsec
;  datamod(2,*)=lon
;  datamod(3,*)=lat
;  datamod(4,*)=alt
;  datamod(5,*)= U velocity
;  datamod(6,*)= V velocity
;  datamod(7,*)= theta
;  datamod(8,*)= pv
;  datamod(9,*)= pres
;  datamod(10,*)=qdf
;  datamod(11,*)=ch4
;  datamod(12,*)=co
;  datamod(13,*)=n2o
;  datamod(14,*)=o3
  case 1 of
    model_species eq 'O3':begin
      sindex=3
      modtrack=reform(datamod(sindex+11,*))
    end
    model_species eq 'CO':begin
      sindex=1
      modtrack=reform(datamod(sindex+11,*))
    end
    model_species eq 'N2O':begin
      sindex=2
      modtrack=reform(datamod(sindex+11,*))
    end
    model_species eq 'CH4':begin
      sindex=0
      modtrack=reform(datamod(sindex+11,*))
    end
endcase
utchr=reform(datamod(1,*),ntime)/(60.*60.)
lon=reform(datamod(2,*),ntime)
lat=reform(datamod(3,*),ntime)
alt=reform(datamod(4,*),ntime)
index=where(modtrack ne -999.)
modtrack(index)=modtrack(index)*scale
!p.multi=[0,1,3]
plot,lon(index),lat(index),xtitle='Longitude',ytitle='Latitude',title=dates(nf)
plot,utchr(index),alt(index)/1000.,xtitle='UTC',ytitle='Altitude (km)',title=dates(nf)
plot,utchr(index),modtrack(index),xtitle='UTC',ytitle='CO (ppbv)',title=dates(nf)
stop
endfor
end
